"""
Default configurations for autograding
"""

DEFAULT_OPTIONS = {
    "score_threshold": None,
    "points_possible": None,
    "show_stdout": False,
    "show_hidden": False,
    "show_all_public": False,
    "seed": None,
    "grade_from_log": False,
    "serialized_variables": {},
    "public_multiplier": 0,
    "pdf": False,
    "token": None,
    "course_id": 'None',
    "assignment_id": 'None',
    "filtering": False,
    "pagebreaks": False,
    "debug": False,
    "autograder_dir": '/autograder',
    "lang": 'python',
    "miniconda_path": '/root/miniconda3',
    "test_visibility": 'hidden',
    "separate_tests": True,
    "plugins": [],
    "logo": True,
    "print_summary": True,
    "print_score": True,
    "zips": False,
}
